@@ -3,7 +3,7 @@ use {
     crate::accountsdb_plugin_manager::AccountsDbPluginManager,
     log::*,
     solana_accountsdb_plugin_interface::accountsdb_plugin_interface::{
-        ReplicaAccountInfo, ReplicaAccountInfoVersions, SlotStatus,
+        ReplicaAccountInfo, ReplicaAccountInfoVersions,
     },
     solana_measure::measure::Measure,
     solana_metrics::*,
@@ -86,18 +86,6 @@ impl AccountsUpdateNotifierInterface for AccountsUpdateNotifierImpl {
             );
         }
     }
-
-    fn notify_slot_confirmed(&self, slot: Slot, parent: Option<Slot>) {
-        self.notify_slot_status(slot, parent, SlotStatus::Confirmed);
-    }
-
-    fn notify_slot_processed(&self, slot: Slot, parent: Option<Slot>) {
-        self.notify_slot_status(slot, parent, SlotStatus::Processed);
-    }
-
-    fn notify_slot_rooted(&self, slot: Slot, parent: Option<Slot>) {
-        self.notify_slot_status(slot, parent, SlotStatus::Rooted);
-    }
 }
 
 impl AccountsUpdateNotifierImpl {
@@ -189,39 +177,4 @@ impl AccountsUpdateNotifierImpl {
             100000
         );
     }
-
-    pub fn notify_slot_status(&self, slot: Slot, parent: Option<Slot>, slot_status: SlotStatus) {
-        let mut plugin_manager = self.plugin_manager.write().unwrap();
-        if plugin_manager.plugins.is_empty() {
-            return;
-        }
-
-        for plugin in plugin_manager.plugins.iter_mut() {
-            let mut measure = Measure::start("accountsdb-plugin-update-slot");
-            match plugin.update_slot_status(slot, parent, slot_status.clone()) {
-                Err(err) => {
-                    error!(
-                        "Failed to update slot status at slot {}, error: {} to plugin {}",
-                        slot,
-                        err,
-                        plugin.name()
-                    )
-                }
-                Ok(_) => {
-                    trace!(
-                        "Successfully updated slot status at slot {} to plugin {}",
-                        slot,
-                        plugin.name()
-                    );
-                }
-            }
-            measure.stop();
-            inc_new_counter_debug!(
-                "accountsdb-plugin-update-slot-us",
-                measure.as_us() as usize,
-                1000,
-                1000
-            );
-        }
-    }
 }
